@@ -25,52 +25,45 @@ class DeleteLaunchTemplateVersionRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Ecs', '2014-05-26', 'DeleteLaunchTemplateVersion','ecs')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_LaunchTemplateName(self):
+	def get_LaunchTemplateName(self): # String
 		return self.get_query_params().get('LaunchTemplateName')
 
-	def set_LaunchTemplateName(self,LaunchTemplateName):
-		self.add_query_param('LaunchTemplateName',LaunchTemplateName)
-
-	def get_ResourceOwnerId(self):
+	def set_LaunchTemplateName(self, LaunchTemplateName):  # String
+		self.add_query_param('LaunchTemplateName', LaunchTemplateName)
+	def get_ResourceOwnerId(self): # Long
 		return self.get_query_params().get('ResourceOwnerId')
 
-	def set_ResourceOwnerId(self,ResourceOwnerId):
-		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
-
-	def get_DeleteVersions(self):
+	def set_ResourceOwnerId(self, ResourceOwnerId):  # Long
+		self.add_query_param('ResourceOwnerId', ResourceOwnerId)
+	def get_DeleteVersions(self): # RepeatList
 		return self.get_query_params().get('DeleteVersion')
 
-	def set_DeleteVersions(self, DeleteVersions):
-		for depth1 in range(len(DeleteVersions)):
-			if DeleteVersions[depth1] is not None:
-				self.add_query_param('DeleteVersion.' + str(depth1 + 1) , DeleteVersions[depth1])
-
-	def get_LaunchTemplateId(self):
+	def set_DeleteVersions(self, DeleteVersion):  # RepeatList
+		for depth1 in range(len(DeleteVersion)):
+			self.add_query_param('DeleteVersion.' + str(depth1 + 1), DeleteVersion[depth1])
+	def get_LaunchTemplateId(self): # String
 		return self.get_query_params().get('LaunchTemplateId')
 
-	def set_LaunchTemplateId(self,LaunchTemplateId):
-		self.add_query_param('LaunchTemplateId',LaunchTemplateId)
-
-	def get_ResourceOwnerAccount(self):
+	def set_LaunchTemplateId(self, LaunchTemplateId):  # String
+		self.add_query_param('LaunchTemplateId', LaunchTemplateId)
+	def get_ResourceOwnerAccount(self): # String
 		return self.get_query_params().get('ResourceOwnerAccount')
 
-	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
-		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)
-
-	def get_OwnerAccount(self):
+	def set_ResourceOwnerAccount(self, ResourceOwnerAccount):  # String
+		self.add_query_param('ResourceOwnerAccount', ResourceOwnerAccount)
+	def get_OwnerAccount(self): # String
 		return self.get_query_params().get('OwnerAccount')
 
-	def set_OwnerAccount(self,OwnerAccount):
-		self.add_query_param('OwnerAccount',OwnerAccount)
-
-	def get_OwnerId(self):
+	def set_OwnerAccount(self, OwnerAccount):  # String
+		self.add_query_param('OwnerAccount', OwnerAccount)
+	def get_OwnerId(self): # Long
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
\ No newline at end of file
+	def set_OwnerId(self, OwnerId):  # Long
+		self.add_query_param('OwnerId', OwnerId)
