@@ -25,42 +25,43 @@ class ResetDisksRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Ecs', '2014-05-26', 'ResetDisks','ecs')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ResourceOwnerId(self):
+	def get_ResourceOwnerId(self): # Long
 		return self.get_query_params().get('ResourceOwnerId')
 
-	def set_ResourceOwnerId(self,ResourceOwnerId):
-		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
+	def set_ResourceOwnerId(self, ResourceOwnerId):  # Long
+		self.add_query_param('ResourceOwnerId', ResourceOwnerId)
+	def get_DryRun(self): # Boolean
+		return self.get_query_params().get('DryRun')
 
-	def get_ResourceOwnerAccount(self):
+	def set_DryRun(self, DryRun):  # Boolean
+		self.add_query_param('DryRun', DryRun)
+	def get_ResourceOwnerAccount(self): # String
 		return self.get_query_params().get('ResourceOwnerAccount')
 
-	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
-		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)
-
-	def get_OwnerAccount(self):
+	def set_ResourceOwnerAccount(self, ResourceOwnerAccount):  # String
+		self.add_query_param('ResourceOwnerAccount', ResourceOwnerAccount)
+	def get_OwnerAccount(self): # String
 		return self.get_query_params().get('OwnerAccount')
 
-	def set_OwnerAccount(self,OwnerAccount):
-		self.add_query_param('OwnerAccount',OwnerAccount)
-
-	def get_OwnerId(self):
+	def set_OwnerAccount(self, OwnerAccount):  # String
+		self.add_query_param('OwnerAccount', OwnerAccount)
+	def get_OwnerId(self): # Long
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
-
-	def get_Disks(self):
+	def set_OwnerId(self, OwnerId):  # Long
+		self.add_query_param('OwnerId', OwnerId)
+	def get_Disks(self): # RepeatList
 		return self.get_query_params().get('Disk')
 
-	def set_Disks(self, Disks):
-		for depth1 in range(len(Disks)):
-			if Disks[depth1].get('DiskId') is not None:
-				self.add_query_param('Disk.' + str(depth1 + 1) + '.DiskId', Disks[depth1].get('DiskId'))
-			if Disks[depth1].get('SnapshotId') is not None:
-				self.add_query_param('Disk.' + str(depth1 + 1) + '.SnapshotId', Disks[depth1].get('SnapshotId'))
\ No newline at end of file
+	def set_Disks(self, Disk):  # RepeatList
+		for depth1 in range(len(Disk)):
+			if Disk[depth1].get('SnapshotId') is not None:
+				self.add_query_param('Disk.' + str(depth1 + 1) + '.SnapshotId', Disk[depth1].get('SnapshotId'))
+			if Disk[depth1].get('DiskId') is not None:
+				self.add_query_param('Disk.' + str(depth1 + 1) + '.DiskId', Disk[depth1].get('DiskId'))
