@@ -25,46 +25,46 @@ class UnassignIpv6AddressesRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Ecs', '2014-05-26', 'UnassignIpv6Addresses','ecs')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ResourceOwnerId(self):
+	def get_ResourceOwnerId(self): # Long
 		return self.get_query_params().get('ResourceOwnerId')
 
-	def set_ResourceOwnerId(self,ResourceOwnerId):
-		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
+	def set_ResourceOwnerId(self, ResourceOwnerId):  # Long
+		self.add_query_param('ResourceOwnerId', ResourceOwnerId)
+	def get_Ipv6Prefixs(self): # RepeatList
+		return self.get_query_params().get('Ipv6Prefix')
 
-	def get_ResourceOwnerAccount(self):
+	def set_Ipv6Prefixs(self, Ipv6Prefix):  # RepeatList
+		for depth1 in range(len(Ipv6Prefix)):
+			self.add_query_param('Ipv6Prefix.' + str(depth1 + 1), Ipv6Prefix[depth1])
+	def get_ResourceOwnerAccount(self): # String
 		return self.get_query_params().get('ResourceOwnerAccount')
 
-	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
-		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)
-
-	def get_OwnerAccount(self):
+	def set_ResourceOwnerAccount(self, ResourceOwnerAccount):  # String
+		self.add_query_param('ResourceOwnerAccount', ResourceOwnerAccount)
+	def get_OwnerAccount(self): # String
 		return self.get_query_params().get('OwnerAccount')
 
-	def set_OwnerAccount(self,OwnerAccount):
-		self.add_query_param('OwnerAccount',OwnerAccount)
-
-	def get_OwnerId(self):
+	def set_OwnerAccount(self, OwnerAccount):  # String
+		self.add_query_param('OwnerAccount', OwnerAccount)
+	def get_OwnerId(self): # Long
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
-
-	def get_NetworkInterfaceId(self):
+	def set_OwnerId(self, OwnerId):  # Long
+		self.add_query_param('OwnerId', OwnerId)
+	def get_NetworkInterfaceId(self): # String
 		return self.get_query_params().get('NetworkInterfaceId')
 
-	def set_NetworkInterfaceId(self,NetworkInterfaceId):
-		self.add_query_param('NetworkInterfaceId',NetworkInterfaceId)
-
-	def get_Ipv6Addresss(self):
+	def set_NetworkInterfaceId(self, NetworkInterfaceId):  # String
+		self.add_query_param('NetworkInterfaceId', NetworkInterfaceId)
+	def get_Ipv6Addresss(self): # RepeatList
 		return self.get_query_params().get('Ipv6Address')
 
-	def set_Ipv6Addresss(self, Ipv6Addresss):
-		for depth1 in range(len(Ipv6Addresss)):
-			if Ipv6Addresss[depth1] is not None:
-				self.add_query_param('Ipv6Address.' + str(depth1 + 1) , Ipv6Addresss[depth1])
\ No newline at end of file
+	def set_Ipv6Addresss(self, Ipv6Address):  # RepeatList
+		for depth1 in range(len(Ipv6Address)):
+			self.add_query_param('Ipv6Address.' + str(depth1 + 1), Ipv6Address[depth1])
